analphipy.measures.Measures
===========================

.. currentmodule:: analphipy.measures

.. autoclass:: Measures

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~Measures.__init__
      ~Measures.boltz_diverg_js
      ~Measures.mayer_diverg_js
      ~Measures.secondvirial
      ~Measures.secondvirial_dbeta
   
   

   
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~Measures.__repr__
   
   